@@ -1,9 +1,10 @@
 import json
+import os
 import sys
 
 from datalake_scripts.common.base_script import BaseScripts
 from datalake_scripts.common.logger import logger
-from datalake_scripts.engines.get_engine import BulkSearch
+from datalake_scripts.engines.post_engine import BulkSearch
 
 
 def main(override_args=None):
@@ -15,7 +16,8 @@ def main(override_args=None):
     parser = starter.start('Retrieve a list of response from a given query hash.')
     parser.add_argument(
         '--query_fields',
-        help='fields to be retrieved from the threat (default: only the hashkey)',
+        help='fields to be retrieved from the threat (default: only the hashkey)\n'
+             'If an atom detail isn\'t present in a particular atom, empty string is returned.',
         nargs='+',
         default=['threat_hashkey'],
     )
@@ -27,7 +29,7 @@ def main(override_args=None):
     required_named = parser.add_argument_group('required arguments')
     required_named.add_argument(
         'query_hash',
-        help='the query hash from which to retrieve the response hashkeys',
+        help='the query hash from which to retrieve the response hashkeys or a path to the query body json file',
     )
     if override_args:
         args = parser.parse_args(override_args)
@@ -37,14 +39,25 @@ def main(override_args=None):
     if len(args.query_fields) > 1 and args.list:
         parser.error("List output format is only available if a single element is queried (via query_fields)")
 
+    query_body = {}
+    query_hash = args.query_hash
+    if len(query_hash) != 32 or os.path.exists(query_hash):
+        try:
+            with open(query_hash, 'r') as query_body_file:
+                query_body = json.load(query_body_file)
+        except FileNotFoundError:
+            logger.error(f"Couldn't understand the given value as a query hash or path to query body: {query_hash}")
+            exit(1)
+
     # Load api_endpoints and tokens
-    endpoint_url, main_url, tokens = starter.load_config(args)
-    logger.debug(f'Start to search for threat from the query hash:{args.query_hash}')
+    endpoint_config, main_url, tokens = starter.load_config(args)
+    logger.debug(f'Start to search for threat from the query hash:{query_hash}')
 
-    url_event = main_url + endpoint_url['endpoints']['bulk-search']
-    bulk_search = BulkSearch(url_event, main_url, tokens)
-
-    response = bulk_search.get_threats(args.query_hash, args.query_fields)
+    bulk_search = BulkSearch(endpoint_config, args.env, tokens)
+    if query_body:
+        response = bulk_search.get_threats(query_body=query_body, query_fields=args.query_fields)
+    else:
+        response = bulk_search.get_threats(query_hash=query_hash, query_fields=args.query_fields)
     original_count = response.get('count', 0)
     logger.info(f'Number of threat that have been retrieved: {original_count}')
 
